"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const Boom = require("boom");
const register = (server, pOptions, next) => {
    const origRoute = server.root.route;
    const innerRoute = (options) => {
        if (options.handler) {
            if (options.handler instanceof Function) {
                const t = options.handler;
                options.handler = (request, reply) => {
                    const p = t(request, reply);
                    if (p && p.catch) {
                        p.catch((e) => {
                            console.error(e.stack);
                            console.error(e.toString());
                            reply(Boom.badGateway('server error'));
                        });
                    }
                };
            }
        }
        return origRoute.apply(server.root, [options]);
    };
    server.root.route = (options) => {
        if (Array.isArray(options)) {
            return options.map(option => innerRoute(option));
        }
        return innerRoute(options);
    };
    Object.keys(origRoute).forEach((k) => {
        server.root.route[k] = origRoute[k];
    });
    next();
};
exports.register = register;
register.attributes = {
    name: 'hapi-es7-async-handler',
    version: '1.0.0',
};
//# sourceMappingURL=index.js.map